find_ros_package(rospy)

# Message-generation support.
macro(genmsg_py)
  get_msgs(_msglist)
  set(_autogen "")
  foreach(_msg ${_msglist})
    # Construct the path to the .msg file
    set(_input ${PROJECT_SOURCE_DIR}/msg/${_msg})
  
    gendeps(${PROJECT_NAME} ${_msg})
  
    set(genmsg_py_exe ${rospy_PACKAGE_PATH}/scripts/genmsg_py)

    set(_output_py ${PROJECT_SOURCE_DIR}/src/${PROJECT_NAME}/msg/_${_msg})
    string(REPLACE ".msg" ".py" _output_py ${_output_py})
  
    # Add the rule to build the .h the .msg
    add_custom_command(OUTPUT ${_output_py} 
                       COMMAND ${genmsg_py_exe} ${_input}
                       DEPENDS ${_input} ${genmsg_py_exe} ${gendeps_exe} ${${PROJECT_NAME}_${_msg}_GENDEPS} ${ROS_MANIFEST_LIST})
    list(APPEND _autogen ${_output_py})
  endforeach(_msg)
  # Create a target that depends on the union of all the autogenerated
  # files
  add_custom_target(ROSBUILD_genmsg_py DEPENDS ${_autogen})
  # Add our target to the top-level genmsg target, which will be fired if
  # the user calls genmsg()
  add_dependencies(rospack_genmsg ROSBUILD_genmsg_py)
endmacro(genmsg_py)

# Call the macro we just defined.
genmsg_py()

# Service-generation support.
macro(gensrv_py)
  get_srvs(_srvlist)
  set(_autogen "")
  foreach(_srv ${_srvlist})
    # Construct the path to the .srv file
    set(_input ${PROJECT_SOURCE_DIR}/srv/${_srv})
  
    gendeps(${PROJECT_NAME} ${_srv})
  
    set(gensrv_py_exe ${rospy_PACKAGE_PATH}/scripts/gensrv_py)

    set(_output_py ${PROJECT_SOURCE_DIR}/src/${PROJECT_NAME}/srv/_${_srv})
    string(REPLACE ".srv" ".py" _output_py ${_output_py})
  
    # Add the rule to build the .h from the .srv
    add_custom_command(OUTPUT ${_output_py} 
                       COMMAND ${gensrv_py_exe} ${_input}
                       DEPENDS ${_input} ${gensrv_py_exe} ${gendeps_exe} ${${PROJECT_NAME}_${_srv}_GENDEPS} ${ROS_MANIFEST_LIST})
    list(APPEND _autogen ${_output_py})
  endforeach(_srv)
  # Create a target that depends on the union of all the autogenerated
  # files
  add_custom_target(ROSBUILD_gensrv_py DEPENDS ${_autogen})
  # Add our target to the top-level gensrv target, which will be fired if
  # the user calls gensrv()
  add_dependencies(rospack_gensrv ROSBUILD_gensrv_py)
endmacro(gensrv_py)

# Call the macro we just defined.
gensrv_py()

